==> scipion_em_tomosegmemtv-3.0.0-py3-none-any.whl: tomosegmemtv/viewers/viewers_data.py <==
# **************************************************************************
# *
# * Authors:     David Herreros Calero (dherreros@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

import pyworkflow.viewer as pwviewer
import pwem.viewers.views as vi

from tomosegmemtv.protocols import ProtAnnotateMembranes
from tomosegmemtv.viewers.annotation_results_viewer import AnnotatedVesicleViewerDialog
from tomosegmemtv.viewers.memb_annotator_results_tree import MembAnnotatorResultsProvider


class Tomo3D4TomoSegMemDataViewer(pwviewer.Viewer):
    """ Wrapper to visualize different type of objects
    using pyvista
    """
    _environments = [pwviewer.DESKTOP_TKINTER]
    _targets = [ProtAnnotateMembranes]

    def __init__(self, **kwargs):
        pwviewer.Viewer.__init__(self, **kwargs)
        self._views = []

    def _getObjView(self, obj, fn, viewParams={}):
        return vi.ObjectView(
            self._project, obj.strId(), fn, viewParams=viewParams)

    def _visualize(self, obj, **kwargs):
        views = []
        cls = type(obj)
        tomoMaskList = [tomoMask.clone() for tomoMask in obj.outputSetofTomoMasks.iterItems()]
        vesicleProvider = MembAnnotatorResultsProvider(tomoMaskList, None, None)

        if issubclass(cls, ProtAnnotateMembranes):
            AnnotatedVesicleViewerDialog(self._tkRoot, provider=vesicleProvider)

        return views

==> scipion_em_tomosegmemtv-3.1.2-py3-none-any.whl: tomosegmemtv/viewers/viewers_data.py <==
# **************************************************************************
# *
# * Authors:     David Herreros Calero (dherreros@cnb.csic.es)
# *
# * Unidad de  Bioinformatica of Centro Nacional de Biotecnologia , CSIC
# *
# * This program is free software; you can redistribute it and/or modify
# * it under the terms of the GNU General Public License as published by
# * the Free Software Foundation; either version 2 of the License, or
# * (at your option) any later version.
# *
# * This program is distributed in the hope that it will be useful,
# * but WITHOUT ANY WARRANTY; without even the implied warranty of
# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# * GNU General Public License for more details.
# *
# * You should have received a copy of the GNU General Public License
# * along with this program; if not, write to the Free Software
# * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# * 02111-1307  USA
# *
# *  All comments concerning this program package may be sent to the
# *  e-mail address 'scipion@cnb.csic.es'
# *
# **************************************************************************

import pyworkflow.viewer as pwviewer
import pwem.viewers.views as vi
from tomo.objects import SetOfTomoMasks
from tomosegmemtv.protocols import ProtAnnotateMembranes
from tomosegmemtv.viewers.annotation_results_viewer import AnnotatedVesicleViewerDialog
from tomosegmemtv.viewers.memb_annotator_results_tree import MembAnnotatorResultsProvider


class TomoViz4TomoSegMemDataViewer(pwviewer.Viewer):
    """ Wrapper to visualize different type of objects
    using pyvista
    """
    _environments = [pwviewer.DESKTOP_TKINTER]
    _targets = [ProtAnnotateMembranes]

    def __init__(self, **kwargs):
        pwviewer.Viewer.__init__(self, **kwargs)
        self._views = []

    def _getObjView(self, obj, fn, viewParams={}):
        return vi.ObjectView(
            self._project, obj.strId(), fn, viewParams=viewParams)

    def _visualize(self, obj, **kwargs):
        views = []
        cls = type(obj)

        tomoMaskList = []
        for name, output in obj.iterOutputAttributes(outputClass=SetOfTomoMasks):
            for tomoMask in output.iterItems():
                tomoMaskList.append(tomoMask.clone())

        vesicleProvider = MembAnnotatorResultsProvider(tomoMaskList, None, None)

        if issubclass(cls, ProtAnnotateMembranes):
            AnnotatedVesicleViewerDialog(self._tkRoot, provider=vesicleProvider)

        return views
